==> BI_parser-0.0.5.tar.gz: BI_parser-0.0.5/src/BI_parser/client.py <==
'''
Contient la classe chargée de traiter, stocker et manipuler les informations liées aux repertoires clients.
'''

import os
from typing import List

from src.BI_parser.script import Script


class Client:
    '''
    description
    '''
    def __init__(self, chemin_du_repertoire: str, id_: str, nom_du_client: str, langage: str) -> None:
        '''
        description
        '''

        self.nom: str = nom_du_client  # temporairement déclaratif
        self.id: str = id_
        self.langage: str = langage  # temporairement déclaratif
        self.chemin: str = chemin_du_repertoire

        self.list_scripts: List[Script] = []
        list_chemin_scripts: List[str] = os.listdir(chemin_du_repertoire)
        for chemin in list_chemin_scripts:
            self.list_scripts.append( \
                    Script(chemin_du_repertoire + '/' + chemin, self.id + '.' + str(len(self.list_scripts) + 1)) \
                    )

    def nb_scripts(self) -> int:
        '''
        description
        '''
        return len(self.list_scripts)

    def nb_blocs(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_blocs()
        return acc

    def nb_requetes(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_requetes()
        return acc

    def nb_commentaires(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_commentaires()
        return acc

    def nb_lignes(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_lignes()
        return acc

    def nb_caracteres(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_caracteres()
        return acc

==> BI_parser-0.0.9.tar.gz: BI_parser-0.0.9/src/BI_parser/client.py <==
'''
Contient la classe chargée de traiter, stocker et manipuler les informations liées aux repertoires clients.
'''

import os
from typing import List

from BI_parser.script import Script


class Client:
    '''
    description
    '''
    def __init__(self, chemin_du_repertoire: str, id_: str, nom_du_client: str, langage: str) -> None:
        '''
        description
        '''

        self.nom: str = nom_du_client  # temporairement déclaratif
        self.id: str = id_
        self.langage: str = langage  # temporairement déclaratif
        self.chemin: str = chemin_du_repertoire

        self.list_scripts: List[Script] = []
        list_chemin_scripts: List[str] = os.listdir(chemin_du_repertoire)
        for chemin in list_chemin_scripts:
            self.list_scripts.append( \
                    Script(chemin_du_repertoire + '/' + chemin, self.id + '.' + str(len(self.list_scripts) + 1)) \
                    )

    def nb_scripts(self) -> int:
        '''
        description
        '''
        return len(self.list_scripts)

    def nb_blocs(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_blocs()
        return acc

    def nb_requetes(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_requetes()
        return acc

    def nb_commentaires(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_commentaires()
        return acc

    def nb_lignes(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_lignes()
        return acc

    def nb_caracteres(self) -> int:
        '''
        description
        '''
        acc = 0
        for script in self.list_scripts:
            acc += script.nb_caracteres()
        return acc
